@@ -6,7 +6,7 @@
 #' of point estimates, thereby urging a level of caution that is consistent
 #' with what the data allows.
 #'
-#' This function used [confIntProp()] to compute confidence intervals
+#' This function uses [ufs::confIntProp()] to compute confidence intervals
 #' for proportions at different levels of confidence. The confidence interval
 #' bounds at those levels of confidence are then used to draw rectangles with
 #' colors in a gradient that corresponds to the confidence level.
@@ -56,22 +56,22 @@
 #' bars of that color).
 #' @param rank.conf Whether to let the fill and color gradients use the confidence
 #' or the ranked confidence.
-#' @param linetype The [linetype()] to use (0 = blank, 1 = solid, 2 =
+#' @param linetype The `linetype` to use (0 = blank, 1 = solid, 2 =
 #' dashed, 3 = dotted, 4 = dotdash, 5 = longdash, 6 = twodash).
 #' @param theme The theme to use.
-#' @param returnPlotOnly Whether to only return the [ggplot2()] plot
+#' @param returnPlotOnly Whether to only return the [ggplot2::ggplot()] plot
 #' or the full object including intermediate values and objects.
 #' @param x The object to print/plot.
-#' @param \dots Any additional arguments are passed on to `print` and
-#' `grid.draw`.
+#' @param \dots Any additional arguments are passed on to [base::print()] and
+#' [grid::grid.draw()].
 #'
-#' @return A [ggplot2()] object (if `returnPlotOnly` is TRUE),
-#' or an object containing that [ggplot2()] object and intermediate
+#' @return A [ggplot2::ggplot()] object (if `returnPlotOnly` is TRUE),
+#' or an object containing that [ggplot2::ggplot()] object and intermediate
 #' products.
 #' @author Gjalt-Jorn Peters
 #'
-#' Maintainer: Gjalt-Jorn Peters <gjalt-jorn@@userfriendlyscience.com>
-#' @seealso [confIntProp()] and [binom.test()]
+#' Maintainer: Gjalt-Jorn Peters <ufs@@opens.science>
+#' @seealso [ufs::confIntProp()] and [stats::binom.test()]
 #' @keywords hplot graphs
 #' @examples
 #'
@@ -152,7 +152,7 @@ ggProportionPlot <- function(dat,
                              theme = ggplot2::theme_bw(),
                              returnPlotOnly = TRUE) {
 
-  if (is.vector(dat) || is.factor(dat)) {
+  if (is.numeric(dat) || is.factor(dat)) {
     if (is.character(dat)) {
       if (all(grepl('\\d+', colnames(dat)))) {
         dat <- as.numeric(dat);
@@ -191,6 +191,9 @@ ggProportionPlot <- function(dat,
         hiCategory <- max(dat[, items], na.rm=TRUE);
       }
     }
+  } else {
+    stop("The object passed as `dat` is not a numeric vector or factor or data.frame, ",
+         "but instead has class ", vecTxtQ(class(dat)), ".");
   }
   if (na.rm) {
     tmpDat <- tmpDat[stats::complete.cases(tmpDat), , drop=FALSE];
