@@ -24,9 +24,9 @@ suspectParticipants <- function(carelessObject,
                                 missingSymbol = "Missing") {
 
   if (!requireNamespace("careless", quietly = TRUE)) {
-    stop("Package \"careless\" needed for this function to work. You can install it using:\n\n",
-         "  install.packages('careless');\n",
-         call. = FALSE);
+    message("Package \"careless\" needed for this function to work. You can install it using:\n\n",
+            "  install.packages('careless');\n");
+    return(invisible(FALSE));
   }
 
   if (inherits(carelessObject, "carelessObject")) {
